@@ -416,7 +416,7 @@ class Client:
                     file_ = (await client.get(file)).content
                 d_file = {"file":file_}
         async with httpx.AsyncClient(verify=False) as cl:
-            response = await cl.post(url, files=d_file)
+            response = await cl.post(url, files=d_file,timeout=9999)
             if response.status_code != 200:
                 logger.error("خطا در آپلود فایل !")
                 raise httpx.HTTPStatusError(
@@ -626,9 +626,10 @@ class Client:
     async def set_endpoint(self, url: str, type: Literal["ReceiveUpdate", "GetSelectionItem", "ReceiveInlineMessage", "ReceiveQuery", "SearchSelectionItems"]) -> props:
         """set endpoint url / تنظیم ادرس اند پوینت"""
         logger.info("استفاده از متود set_endpoint")
-        return props(await self.send_requests(
+        result = await self.send_requests(
             "updateBotEndpoints", {"url": url, "type": type}
-        ))
+        )
+        return props(result)
 
     @async_to_sync
     async def set_token_fast_rub(self) -> bool:
@@ -745,7 +746,6 @@ class Client:
                     self.last.append(message['new_message']['message_id'])
                     if len(self.last) > 500:
                         self.last.pop(-1)
-                    print(message)
                     update_obj = Update(message, self)
                     for handler in self._message_handlers:
                         await handler(update_obj)
